@@ -1,4 +1,3 @@
-import json
 import sys
 import yaml
 
@@ -24,9 +23,10 @@ from rich.syntax import Syntax
 from rich.table import Column, Table
 from rich.theme import Theme
 
-from clipped.humanize import humanize_attrs
-from clipped.list_utils import to_list
-from clipped.units_processors import to_unit_memory
+from clipped.utils.humanize import humanize_attrs
+from clipped.utils.json import orjson_dumps, orjson_loads, orjson_pprint_option
+from clipped.utils.lists import to_list
+from clipped.utils.units import to_unit_memory
 
 
 class Printer:
@@ -70,7 +70,7 @@ class Printer:
     @staticmethod
     def pprint(value):
         """Prints as formatted JSON"""
-        click.echo(json.dumps(value, sort_keys=True, indent=4, separators=(",", ": ")))
+        click.echo(orjson_dumps(value, option=orjson_pprint_option))
 
     @classmethod
     def print_md(cls, md: str):
@@ -92,8 +92,8 @@ class Printer:
     @classmethod
     def print_json(cls, value: any):
         if isinstance(value, str):
-            value = json.loads(value)
-        value = json.dumps(value, sort_keys=True, indent=4, separators=(",", ": "))
+            value = orjson_loads(value)
+        value = orjson_dumps(value, option=orjson_pprint_option)
         syntax = Syntax(value, "json", theme="dracula", line_numbers=False)
         cls.console.print(syntax)
 
@@ -135,7 +135,7 @@ class Printer:
         text: str,
         sys_exit: bool = False,
         command_help: Optional[str] = None,
-        **kwargs
+        **kwargs,
     ):
         cls.console.print(text, style="error")
         if command_help:
